---
title: 群组概述
sidebar_position: 10
---
import { Support } from '/docs/assets/scripts/support.js';

# 群组概述

群聊是即时通讯类应用中常见的多人通讯方式，一般包含两个及以上的用户。融云的群组业务支持丰富的群组成员管理、禁言管理等特性，支持离线消息推送和历史消息记录漫游，可用于兴趣群、办公群、客服服务沟通等。IMKit 提供开箱即用的群聊会话 UI 组件。

## 服务配置
<!--public-cloud-only start-->
客户端 SDK 默认支持群组业务，不需要申请开通。部分基础功能与增值服务可以在控制台的[免费基础功能]和 [IM 服务管理]页面进行开通和配置。
<!--public-cloud-only end-->
- App Key 下可创建的群组数量无限制。单个用户可加入的群组数量无限制。
- 群组有容量上限，默认群组成员数量上限为 3000 人，可<Support cloudType='private'/>修改。<!--public-cloud-only start-->
- 默认情况下，App Key 未开通**单群聊消息云端存储**服务。您可以自助开通，详见 [开通单群聊消息云存储服务](https://help.rongcloud.cn/t/topic/1071)。如果是生产环境的 App Key，仅 **IM 旗舰版**、**IM 尊享版**可开通该服务。
- 默认情况下，用户只能查看他们加入群组后的群聊消息。开启服务后，新入群用户可以获取他们加入群组之前的群聊历史消息。详见[开通新用户获取加入群组前历史消息服务](https://help.rongcloud.cn/t/topic/1074)。<!--public-cloud-only end-->

## 客户端 SDK 使用须知

- 客户端 SDK（IMKit/IMLib）均不提供群组管理的 API。如需创建群组，必须由 App 服务器请求融云服务端 API 实现。其他操作例如解散群组、加入群组、退出群组等群组管理操作，均须由 App 服务器请求融云服务端 API 实现。详见下方[群组管理功能](#群组管理功能)。
- 群主、群管理员、群公告、邀请入群、群号搜索等均为群组业务逻辑，需在 App 侧自行实现。
- 融云只负责将消息传达给群组中的所有用户，不维护群组成员的资料（头像、名称、群成员名片等）。App 需要自行在业务服务器上维护相关数据，并实现 IMKit 的相关接口，向 IMKit 提供数据。参见下方文档：
    - [群组信息](./group-info.md)
    - [群成员用户信息](./group-userinfo.md)
    - [群组成员列表](./group-member.md)

## 群组管理功能

对于客户端开发人员来说，创建群组、解散等基础管理操作只需要与 App 自身的业务服务端交互即可，由 App 服务端负责调用相应的融云服务端 API（Server API）接口完成相关操作。

| 服务端 API | 功能描述 |
|---|---|
| [创建群组]、[解散群组] | 提供创建者用户 ID、群组 ID、和群名称，向融云服务端申请建群。如解散群组，则群成员关系不复存在。 |
| [加入群组]、[退出群组] | 加入群组后，默认可查看入群以后产生的新消息。退出群组后，不再接收该群的新消息。 |
| [刷新群组信息] | 修改在融云推送服务中使用的群组信息。 |
| [查询群组成员] | 查询指定群组所有成员的用户 ID 信息。 |
| [查询用户所在群组] | 根据用户 ID 查询该用户加入的所有群组，返回群组 ID 及群组名称。融云不存储群组资料信息，群组资料及群成员信息需要开发者在应用服务器自行维护，如应用服务端维护的用户群组关系有缺失时，可通过此接口来核对校验。 |
| [同步用户所在群组] | 向融云服务端同步指定用户当前所加入的所有群组，防止应用中的用户群组信息与融云服务端的用户所属群信息不一致。如果在集成融云服务前 App Server 上已有群组及成员数据，第一次连接融云服务器时，可使用此接口向融云同步已有的用户与群组对应关系。 |
| [禁言指定群成员] | 在指定的单个群组中或全部群组中，禁言一个或多个用户。被禁言用户可以接收查看群组中其他用户消息，但不能通过客户端 SDK 发送消息。 |
| [设置群组全体禁言] | 将群组全体成员禁言。被禁言群组的所有成员均不能发送消息，需要某些用户可以发言时，可将此用户加入到群禁言用户白名单中。 |
| [加入群组全体禁言白名单] | 群组被整体禁言后，禁言白名单中用户可以发送群消息。 |

<!-- 链接区域 -->
[提交工单]: https://console.rongcloud.cn/agile/formwork/ticket/create
[IM 服务管理]: https://console.rongcloud.cn/agile/formwork/advance/index
[免费基础功能]: https://console.rongcloud.cn/agile/formwork/baseService/index
<!-- client api-->
<!-- Server API -->
[创建群组]: /platform-chat-api/group/create-group
[解散群组]: /platform-chat-api/group/dismiss-group
[加入群组]: /platform-chat-api/group/join-group
[退出群组]: /platform-chat-api/group/quit-group
[查询群组成员]: /platform-chat-api/group/query-group-member
[同步用户所在群组]: /platform-chat-api/group/sync-group
[查询用户所在群组]: /platform-chat-api/group/query-group-by-user
[刷新群组信息]: /platform-chat-api/group/refresh-group-info
[禁言指定群成员]: /platform-chat-api/group/mute/gag-user
[设置群组全体禁言]: /platform-chat-api/group/mute/ban-group
[加入群组全体禁言白名单]: /platform-chat-api/group/mute/add-to-group-ban-whitelist

